@@ -8,7 +8,6 @@ from debater_python_api.api.clients.abstract_client import AbstractClient
 from debater_python_api.utils.general_utils import get_default_request_header
 from typing import List, Optional, Dict
 from debater_python_api.utils.kp_analysis_utils import print_progress_bar
-
 from debater_python_api.api.clients.key_point_analysis.KpaExceptions import KpaIllegalInputException
 
 domains_endpoint = '/domains'
@@ -32,17 +31,20 @@ class KpAnalysisClient(AbstractClient):
         AbstractClient.__init__(self, apikey)
         self.host = host if host is not None else 'https://keypoint-matching-backend.debater.res.ibm.com'
 
-    def _delete(self, url, params, use_cache=True, timeout=300, retries=10):
-        return self._run_request_with_retry(requests.delete, url, params, use_cache, timeout, retries)
+    def _delete(self, url, params, use_cache=True, timeout=300, retries=10, headers=None):
+        return self._run_request_with_retry(requests.delete, url, params, use_cache, timeout, retries, headers)
 
-    def _get(self, url, params, use_cache=True, timeout=300, retries=10):
-        return self._run_request_with_retry(requests.get, url, params, use_cache, timeout, retries)
+    def _get(self, url, params, use_cache=True, timeout=300, retries=10, headers=None):
+        return self._run_request_with_retry(requests.get, url, params, use_cache, timeout, retries, headers)
 
-    def _post(self, url, body, use_cache=True, timeout=300, retries=10):
-        return self._run_request_with_retry(requests.post, url, body, use_cache, timeout, retries)
+    def _post(self, url, body, use_cache=True, timeout=300, retries=10, headers=None):
+        return self._run_request_with_retry(requests.post, url, body, use_cache, timeout, retries, headers)
 
-    def _run_request_with_retry(self, func, url, params, use_cache=True, timeout=20, retries=10):
+    def _run_request_with_retry(self, func, url, params, use_cache=True, timeout=20, retries=10, headers_input=None):
         headers = get_default_request_header(self.apikey)
+        if headers_input is not None:
+            headers.update(headers_input)
+
         logging.info('client calls service (%s): %s' % (func.__name__, url))
         if not use_cache:
             headers['cache-control'] = 'no-cache'
@@ -170,8 +172,8 @@ class KpAnalysisClient(AbstractClient):
               * arg_min_len (Integer, set to 4 by default): Filter shorter sentences (by number of tokens).
               * arg_max_len (Integer, set to 36 by default): Filter longer sentences (by number of tokens).
               * arg_relative_aq_threshold (Float in [0.0,1.0], set to 1.0 by default): Filter sentences having a quality score below this precentile (useful to filter out low quality data in the data-set).
-              * clustering_threshold (Float in [0.0,1.0], set to 0.99 by default): Used for key points selection: choose higher values for more fine-grained key points, and lower for more distinct key points.
-              * mapping_threshold (Float in [0.0,1.0], set to 0.99 by default): The matching threshold, scores above are considered a match. A higher threshold leads to a higher precision and a lower coverage.
+              * mapping_policy (String in ["STRICT","NORMAL","LOOSE"], "NORMAL" by default): Policy for determining if an argument is matched to a key point: for “STRICT”, only pairs with high matching
+              scores are considered matched, leading to a higher precision and a lower coverage, and vice versa for "LOOSE".
               * sentence_to_multiple_kps (Boolean, False by default): When True, a sentence is matched to all key points with score above threshold. Otherwise only to one key point with highest match score above threshold.
               * n_top_kps (Integer, default is set by an internal algorithm): Number of key points to generate. Lower value will make the job finish faster. All sentences are re-mapped to these key point.
               * kp_relative_aq_threshold (Float in [0.0,1.0], set to 0.65 by default): Sentences having AQ score below this precentile will not be selected as key point candidates.
@@ -235,8 +237,8 @@ class KpAnalysisClient(AbstractClient):
         :param comments_ids: (optional) a list of comment ids (a list of strings). When not provided, dummy comment_ids will be generated (1, 2, 3,...). When provided, comment_ids must be unique, must be the same length as comments_texts and the comment_id and comment_text should match by position in the list.
         :return: a json with the result
         '''
-        if len(comments_texts) > 1000:
-            raise Exception('Please use the stagged mode (upload_comments, start_kp_analysis_job) for jobs with more then 1000 comments')
+        if len(comments_texts) > 10000:
+            raise Exception('Please use the stagged mode (upload_comments, start_kp_analysis_job) for jobs with more then 10000 comments')
 
         if comments_ids is None:
             comments_ids = [str(i) for i in range(len(comments_texts))]
